r"""Linear mixed model package."""

from .lmm import LMM
from .scan import FastScanner

__all__ = ['LMM', 'FastScanner']
